# Generated by Django 5.1.1 on 2025-09-17 07:30

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("enterprise_models", "0001_initial"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AddField(
            model_name="contractor",
            name="contractor_number",
            field=models.CharField(blank=True, max_length=50, null=True, unique=True),
        ),
        migrations.AddField(
            model_name="contractor",
            name="effective_end_date",
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="contractor",
            name="effective_start_date",
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="contractor",
            name="l1_head",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="l1_contractor",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
        migrations.AddField(
            model_name="contractor",
            name="l2_head",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="l2_contractor",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
        migrations.AddField(
            model_name="contractor",
            name="status",
            field=models.CharField(
                choices=[("Active", "Active"), ("Inactive", "Inactive")],
                db_index=True,
                default="Active",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="department",
            name="description",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="contractor",
            name="contractor_name",
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name="contractor",
            name="description",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="department",
            name="department_name",
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name="department",
            name="department_number",
            field=models.CharField(blank=True, max_length=50, null=True, unique=True),
        ),
    ]
